Getting Started
---------------

- `Overview of TUF <OVERVIEW.rst>`_
- `Installation <INSTALLATION.rst>`_
- Beginner Tutorials (using the basic command-line interface):
   - `Quickstart <QUICKSTART.md>`_
   - `CLI Documentation and Examples <CLI.md>`_
- `Advanced Tutorial <TUTORIAL.md>`_
- `Guidelines for Contributors <CONTRIBUTORS.rst>`_
